@@ -2,4 +2,5 @@ from autoIserv.login import *
 from autoIserv.Session import Session
 from autoIserv.Email import Email
 from autoIserv.Exercise import Exercise
-from . import Modules
\ No newline at end of file
+from autoIserv.Module import Module
+from autoIserv import Modules
\ No newline at end of file
